########################################################################################################################################
########## MS Hyperdominance and habitat drives fish foraging on Atlantic oceanic islands ##############################################
########################################################################################################################################


########################################################################################################################################
################################## -------- Installing and Loading packages ------- ####################################################
########################################################################################################################################


install.packages(c("lme4","ggplot2","vegan","dplyr","tidyr","ggdendro","dendextend","rnaturalearth","rnaturalearthdata","ggspatial",
                   "circlize","gridExtra","grid","sf","maps","maptools","raster","sdmpredictors","RColorBrewer","png","ISLR","scales"))


packs <- c("lme4","ggplot2","vegan","dplyr","tidyr","ggdendro","dendextend","rnaturalearth","rnaturalearthdata","ggspatial","circlize",
           "gridExtra","grid","sf","maps","maptools","raster","sdmpredictors","RColorBrewer","png","ISLR","scales")


lapply(packs, require, character.only = TRUE)

options(scipen = 999) #unable Scientific notation


########################################################################################################################################
############################################# -------- Fig. 1 - Islands MAP ------- ####################################################
########################################################################################################################################


map_theme <-
    function()
       {theme(axis.text.y = element_text(colour="black", size=8, angle=0, hjust=0.5, vjust=0.5, face="plain"),
              axis.text.x = element_text(colour="black", size=8, angle=0, hjust=0.5, vjust=0.0, face="plain"),
              #
              panel.grid.minor = element_blank(), 
              panel.background = element_blank(),
              strip.background = element_blank(),
              #
              axis.line.y = element_line(size=0.5, colour="black", lineend ="butt"),
              axis.line.x = element_line(size=0.5, colour="black", lineend ="butt"),
              # 
              axis.ticks.length = unit(0.2, "cm"),
              axis.ticks.y = element_line(size=0.5, colour="black", lineend ="butt"),
              axis.ticks.x = element_line(size=0.5, colour="black", lineend ="butt"),
              # 
              axis.title.x = element_text(hjust=0.5, vjust=-2, colour="black", size=12, face="bold"),
              axis.title.y = element_text(hjust=0.5, vjust=3, colour="black", size=12, face="bold"),
              #
              legend.position = "none",
              #
              plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, "cm"))}



local      <- c( "FNO",  "ROC", "SPSPA",  "TRI", "ASC")
lat_point  <- c(-03.84, -03.87,  00.92, -20.49,  -7.94)
lon_point  <- c(-32.42, -33.80, -29.34, -29.33, -14.36)
lat_txt    <- c(-05.00, -02.50,  02.30, -19.50,  -6.80)
lon_txt    <- c(-31.00, -35.00, -28.00, -29.33, -14.36)


location   <- data.frame(local,lat_point,lon_point,lat_txt, lon_txt)


world <- ne_countries(scale = "medium", returnclass = "sf")


map <- ggplot() +
          geom_sf(data=world, color="black", fill="grey80")+
          xlab("Longitude")+ 
          ylab("Latitude")+
          coord_sf(xlim=c(-52.0, -10.0), ylim=c(-35.0, 5.0), expand=FALSE)+
          scale_x_discrete(breaks=c(-50,-45,-40,-35,-30,-25,-20,-15),
                           labels=c("50°W","45°W","40°W","35°W","30°W","25°W","20ºW","15°W"))+
          annotate(geom="text", x=-48, y=-11, label="Brazil", fontface="plain", color="grey22", size=6) +
          geom_text(data=location, aes(lon_txt,lat_txt, label=local), fontface="bold", colour="black", size=3)+
          geom_point(data=location, aes(lon_point,lat_point), col="black", bg="black", pch=21, size=1, stroke=1)+
          annotation_scale(data=world, location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7) +
          annotation_north_arrow(location="br", which_north="true", pad_x=unit(2, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
          map_theme()


############# SPSPA ################


penedos <- st_read("./shapefiles/ASPSP_pol.shp")

penedos_map <- 
     ggplot() +
        geom_sf(data=penedos, color="grey50", fill="grey50")+
        xlab(NULL)+ 
        ylab(NULL)+
        coord_sf(xlim=c(-29.3472, -29.3438), ylim=c(0.9148, 0.9192), expand=FALSE)+
        scale_x_discrete(breaks=c(-29.347,-29.346,-29.345,-29.344), 
                         labels=c("29.347°W","29.346°W","29.345°W","29.344°W"))+
        scale_y_discrete(breaks=c(0.915,0.916,0.917,0.918,0.919), 
                         labels=c("0.915°N","0.916°N","0.917°N","0.918°N","0.919°N"))+
        annotate(geom="text", x=-29.3465, y=0.9189, label="ASPSP", fontface="bold", color="black", size=5)+
        geom_point(aes(x=-29.3457, y=0.91735), shape=23, size=4, col="red", fill="red")+
        annotation_scale(location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7)+
        annotation_north_arrow(location="br", which_north="true", pad_x=unit(2, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
        map_theme() 



############# ASCENSION ############


ascension <- st_read("./shapefiles/Ascension_pol.shp")

ascension_map <- 
     ggplot() +
        geom_sf(data=ascension, color="grey50", fill="grey50")+
        xlab(NULL)+ 
        ylab(NULL)+
        coord_sf(xlim=c(-14.444, -14.276), ylim=c(-8.024, -7.856), expand=FALSE)+
        scale_x_discrete(breaks=c(-14.44,-14.40,-14.36,-14.32,-14.28), labels=c("14.44°W","14.40°W","14.36°W","14.32°W","14.28°W"))+
        scale_y_discrete(breaks=c(-8.02,-7.98,-7.94,-7.90,-7.86), labels=c("8.02°S","7.98°S","7.94°S","7.90°S","7.86°S"))+
        annotate(geom="text", x=-14.42, y=-7.87, label="Ascension", fontface="bold", color="black", size=5)+
        geom_point(aes(x=-14.384719, y=-7.888847), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-14.339026, y=-7.910008), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-14.406990, y=-7.910291), shape=23, size=4, col="red", fill="red")+
        annotation_scale(location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7)+
        annotation_north_arrow(location="br", which_north="true", pad_x=unit(2.4, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
        map_theme()



############# NORONHA ##############


noronha <- st_read("./shapefiles/Noronha_pol.shp")

noronha_map <- 
     ggplot() +
        geom_sf(data=noronha, color="grey50", fill="grey50")+
        xlab(NULL)+ 
        ylab(NULL)+
        coord_sf(xlim=c(-32.482, -32.368), ylim=c(-3.905, -3.795), expand=FALSE)+
        scale_x_discrete(breaks=c(-32.48,-32.46,-32.44,-32.42,-32.40,-32.38), labels=c("32.48°W","32.46°W","32.44°W","32.42°W","32.40°W","32.38°W"))+
        scale_y_discrete(breaks=c(-3.90,-3.88,-3.86,-3.84,-3.82,-3.80), labels=c("3.90°S","3.88°S","3.86°S","3.84°S","3.82°S","3.80°S"))+
        annotate(geom="text", x=-32.455, y=-3.802, label="Fernando de Noronha", fontface="bold", color="black", size=5)+
        geom_point(aes(x=-32.392, y=-3.806), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-32.441, y=-3.845), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-32.474, y=-3.871), shape=23, size=4, col="red", fill="red")+  
        #annotate(geom="text", x=-32.396, y=-3.805, label="Cagarras", fontface="bold", color="black", size=3)+
        #annotate(geom="text", x=-32.441, y=-3.841, label="Laje dos Dois\n Irmãos", fontface="bold", color="black", size=3)+
        #annotate(geom="text", x=-32.474, y=-3.868, label="Ponta da \n Sapata", fontface="bold", color="black", size=3)+ 
        annotation_scale(location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7)+
        annotation_north_arrow(location="br", which_north="true", pad_x=unit(2.2, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
        map_theme()


############# ROCAS ################


rocas <- st_read("./shapefiles/Rocas_pol.shp")

rocas_map <- 
     ggplot() +
        geom_sf(data=rocas, color="grey50", fill="grey50")+
        xlab(NULL)+ 
        ylab(NULL)+
        coord_sf(xlim=c(-33.83, -33.78), ylim=c(-3.845, -3.88), expand=FALSE)+
        scale_x_discrete(breaks=c(-33.82,-33.81,-33.80,-33.79), labels=c("33.82°W","33.81°W","33.80°W","33.79°W"))+
        scale_y_discrete(breaks=c(-3.87,-3.86,-3.85), labels=c("3.87°S","3.86°S","3.85°S"))+
        geom_point(aes(x=-33.819, y=-3.860), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-33.817, y=-3.867), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-33.8125, y=-3.872), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-33.804, y=-3.874), shape=23, size=4, col="red", fill="red")+
        annotate(geom="text", x=-33.82, y=-3.847, label="Rocas Atoll", fontface="bold", color="black", size=5)+
        annotation_scale(location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7)+
        annotation_north_arrow(location="br", which_north="true", pad_x=unit(1.8, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
        map_theme()


############# TRINDADE #############


trindade <- st_read("./shapefiles/Ilha_Trindade_pol.shp")

trindade_map <- 
     ggplot() +
        geom_sf(data=trindade, color="grey50", fill="grey50")+
        xlab(NULL)+ 
        ylab(NULL)+
        coord_sf(xlim=c(-29.352, -29.288), ylim=c(-20.542, -20.478), expand=FALSE)+
        scale_x_discrete(breaks=c(-29.35,-29.34,-29.33,-29.32,-29.31,-29.30,-29.29), labels=c("29.38°W","29.34°W","29.33°W","29.32°W","29.31°W","29.30°W","29.29°W"))+
        scale_y_discrete(breaks=c(-20.54,-20.53,-20.52,-20.51,-20.50,-20.49,-20.48), labels=c("20.54°S","20.53°S","20.52°S","20.51°S","20.50°S","20.49°S","20.48°S"))+
        annotate(geom="text", x=-29.30, y=-20.485, label="Ilha da Trindade", fontface="bold", color="black", size=5)+
        geom_point(aes(x=-29.318, y=-20.499), shape=23, size=4, col="red", fill="red")+  
        geom_point(aes(x=-29.340, y=-20.487), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-29.333, y=-20.523), shape=23, size=4, col="red", fill="red")+
        geom_point(aes(x=-29.303, y=-20.513), shape=23, size=4, col="red", fill="red")+
        annotation_scale(location="br", width_hint=0.3, bar_cols=c("black","white"), line_width=0.5,
                           height=unit(0.2, "cm"), pad_x=unit(1, "cm"), pad_y=unit(0.5, "cm"), text_cex=0.7)+
        annotation_north_arrow(location="br", which_north="true", pad_x=unit(1.5, "cm"), pad_y=unit(0.9, "cm"), 
                                 style=north_arrow_fancy_orienteering, height=unit(1, "cm"), width=unit(1, "cm"))+
        map_theme()



Fig1 <- grid.arrange(map, penedos_map, rocas_map, noronha_map, trindade_map, ascension_map, widths=c(10,10), ncol=2)

ggsave(Fig1, width = 30, height = 45, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. 1 - Islands map.pdf", useDingbats = FALSE)





###########################################################################################################################################
################################# -------- Preparing benthic and fish database ------- ####################################################
###########################################################################################################################################


benthic_df1 <- read.csv("./database/benthic_data.csv", head=T, dec=",", sep=";")

benthic_df2 <- benthic_df1 %>%
                 group_by(video_code,location,functional_group)%>%
                   summarise(cover=sum(cover))%>%
                     as.data.frame()%>%
                       group_by(video_code,location)%>%
                         spread(key=functional_group, value=cover) %>%
                           replace(is.na(.), 0) %>%
                              as.data.frame()



fish_df1 <- read.csv("./database/feeding_data.csv", head=T, dec=",", sep=";")


fish_df2 <- fish_df1[,c(1,4,14,23)] %>%
                 group_by(video_code,location,functional_group)%>%
                   summarise(feeding_pressure=sum(feeding_pressure))%>%
                     as.data.frame()%>%
                       group_by(video_code,location)%>%
                         spread(key=functional_group, value=feeding_pressure) %>%
                           replace(is.na(.), 0) %>%
                              as.data.frame()



###########################################################################################################################################
################################# -------- Gathering fish and benthic databases ------- ###################################################
###########################################################################################################################################


df_final <- left_join(benthic_df2, fish_df2, by=c("video_code","location"))
df_final <- df_final[!(df_final$herbivore_detritivore > 1000), ]                                        #removing sample which FP > 1000

df_final$location[df_final$location == "rocas_atoll"]         <- "Rocas"
df_final$location[df_final$location == "spspa"]               <- "SPSPA"
df_final$location[df_final$location == "fernando_de_noronha"] <- "Noronha"
df_final$location[df_final$location == "trindade_island"]     <- "Trindade"
df_final$location[df_final$location == "ascension"]           <- "Ascension"


df_final <- df_final[,-c(14,17)] %>%                              #removing macrocarnivores and planktivores due to low feeding pressure
              group_by(location) %>% 
               mutate(id = row_number())%>%
                mutate(name = paste0(location,"_",id))%>%
                 as.data.frame()




###########################################################################################################################################
################################# -------- Fig. S1 and habitats matching -------- #########################################################
###########################################################################################################################################


bentos_clust <- df_final[,c(3:11)]
rownames(bentos_clust) <- df_final[,19]


dendr <- bentos_clust %>%
  vegdist(method="euclidian") %>%
    hclust(method="complete") %>%
      as.dendrogram() %>%
        set("labels_cex", 0.5)%>%
          set("branches_lwd", 1) %>%
            set("branches_lty", 1) %>%
              set("labels_color", value=c("plum","green4","palegreen2","yellow3","burlywood4"), k=5)%>%
                set("branches_k_color", value=c("plum","green4","palegreen2","yellow3","burlywood4"), k=5)



#simil <- vegdist(bentos_clust, method="euclidian")
#clust <- hclust(simil, "complete")
#clustcof <- cophenetic(clust)
#cor(simil, clustcof)                                                         #Cophenetic = 0.70 indicating distortion on the dendogram



pdf("D:/Publicações/(2023) Ms. Ferrari et al. - Island interactions/Rstuff/figures_pdf/Fig. S1 - Cluster.pdf", width=8, height=8)

circlize_dendrogram(dendr, facing = "outside", dend_track_height=0.7, labels_track_height=0.1)

dev.off()



cut <- cutree(dendr, k=5, h=50) %>% as.data.frame()


final <- cbind(df_final$video_code, df_final$location, cut, df_final[,c(3:ncol(df_final))])
final <- final[,-19]
head(final)
names(final)[1] <- "video_code"
names(final)[2] <- "location"
names(final)[3] <- "habitat"
names(final)[19] <- "sample_code"

final$habitat[final$habitat == "1"] <- "EAM"
final$habitat[final$habitat == "2"] <- "SAND"
final$habitat[final$habitat == "3"] <- "MALG"
final$habitat[final$habitat == "4"] <- "ZOAN"
final$habitat[final$habitat == "5"] <- "CCA"

final %>% count(habitat)


write.csv(final, "dataframe.csv", row.names = FALSE)




###########################################################################################################################################
######################################## -------- Fig. 2 - Benthic Composition -------- ###################################################
###########################################################################################################################################

df <- read.csv("dataframe.csv", head=T)


df_benth <- df[,c(2,4,5,6,7,8,9,10,11,12)]%>%
              gather(functional_group, cover, cca:zoanthid)%>%
                group_by(location,functional_group) %>%
                  summarize(soma_cover=sum(cover))%>%  
                     mutate(prop_cover = soma_cover/sum(soma_cover))%>%
                        as.data.frame()


Fig2a <- 
ggplot(data=df_benth, aes(x=prop_cover, y=location, 
     fill=factor(functional_group, levels=c("cca","coral","zoanthid","macroalgae","turf","cyanobacteria",
                                            "filter_invertebrates","other_invertebrates","sediment"))))+ 
     geom_bar(stat="identity", position=position_stack(reverse=TRUE), width=0.9)+
     scale_fill_manual(values=alpha(c("plum","maroon2","yellow3","green4","palegreen3","pink4","sienna2","skyblue3","burlywood4"), 0.8), 
                       labels=c("CCA","CORAL","ZOAN","MALG","EAM","CYANO","FILTER","INVE","SEDM"))+
     scale_y_discrete(limits=c("Trindade","Ascension","Rocas","Noronha","SPSPA"), 
                      labels=c("TRI","ASC","ROC","FNO","SPSPA"))+
     scale_x_continuous(breaks=c(0,0.2,0.4,0.6,0.8,1), position="top")+
     ggtitle("Prop. benthic cover")+
     theme(axis.text.x = element_text(colour="black",size=12, angle=00, hjust=0.5, vjust=0.5, face="bold"),
           axis.text.y = element_text(colour="black",size=12, angle=00, hjust=0.5, vjust=0.5, face="bold"),
           panel.grid.minor = element_blank(), 
           panel.background = element_blank(),
           strip.background = element_blank(),
           strip.text.y = element_blank(),
           axis.line.x = element_line(size=1, colour="black", lineend ="butt"),
           axis.line.y = element_blank(),
           axis.ticks.x = element_line(size = 1, colour="black", lineend ="butt"),
           axis.ticks.length = unit(0.2, "cm"),
           axis.ticks.y = element_blank(),
           axis.title.x = element_blank(),
           axis.title.y = element_blank(),
           plot.title = element_text(size=12, hjust=0.5, vjust=1, face="bold", margin=margin(t=2, b=5)),
           legend.position = "bottom",
           legend.title = element_blank(),
           legend.justification = c(0.5,0.5),
           legend.spacing.x = unit(0.6, "cm"),
           legend.box.spacing = unit(0, "cm"),
           legend.key = element_rect(size=0.5),
           legend.key.height=unit(0.8,"line"),
           legend.key.width=unit(0.8,"line"),
           legend.text = element_text(margin = margin(0, 0, 0, -0.5, "cm"), color="black", size=9, face="plain"),
           plot.margin = margin(t=0, r=0.2, b=0.1, l=0, "cm"))


ggsave(Fig2a, width = 20, height = 22, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. 2 - Benthos.pdf", useDingbats = FALSE)




########################################################################################################################################
######################################### -------- Fig. 2 - Feeding Pressure -------- ##################################################
########################################################################################################################################

df_fish <- df[,c(1,2,13,14,15,16,17,18)]%>%
  gather(functional_group, feeding_pressure, herbivore_detritivore:territorial_herbivore)%>%
  group_by(location,functional_group) %>%
  summarize(soma_fp=sum(feeding_pressure))%>%  
  mutate(prop_fp = soma_fp/sum(soma_fp))%>%
  as.data.frame()


Fig2b <- 
  ggplot(data=df_fish, aes(x=prop_fp, y=location,
                           fill=factor(functional_group, levels=c("territorial_herbivore","herbivore_detritivore","macroalgivore",
                                                                  "omnivore","mobile_invertebrate","sessil_invertebrate"))))+ 
  geom_bar(stat="identity", position=position_stack(reverse=TRUE), width=0.9)+
  scale_fill_manual(values=alpha(c("territorial_herbivore"="yellowgreen",
                                   "herbivore_detritivore"="seagreen1", 
                                   "macroalgivore"="darkgreen", 
                                   "omnivore"="blue4", 
                                   "mobile_invertebrate"="orange", 
                                   "sessil_invertebrate"="gold1"),0.8), 
                    labels=c("THER","HERD","MALG","OMNI","MINV","SINV"))+
  scale_x_continuous(breaks=c(0,0.2,0.4,0.6,0.8,1), position="top")+
  scale_y_discrete(limits=c("Trindade","Ascension","Rocas","Noronha","SPSPA"), 
                   labels=c("TRI","ASC","ROC","FNO","SPSPA"))+
  ggtitle("Prop. feeding pressure")+
  theme(axis.text.x = element_text(colour="black",size=8, angle=00, hjust=0.5, vjust=0.5, face="bold"),
        axis.text.y = element_text(colour="black",size=8, angle=00, hjust=0.5, vjust=0.5, face="bold"),
        panel.grid.minor = element_blank(), 
        panel.background = element_blank(),
        strip.background = element_blank(),
        strip.text.y = element_blank(),
        axis.line.x = element_line(size=1, colour="black", lineend ="butt"),
        axis.line.y = element_blank(),
        axis.ticks.x = element_line(size = 1, colour="black", lineend ="butt"),
        axis.ticks.length = unit(0.2, "cm"),
        axis.ticks.y = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        plot.title = element_text(size=12, hjust=0.5, vjust=1, face="bold", margin=margin(t=2, b=5)),
        legend.position = "bottom",
        legend.title = element_blank(),
        legend.justification = c(0.5,0.5),
        legend.spacing.x = unit(0.6, "cm"),
        legend.box.spacing = unit(0, "cm"),
        legend.key = element_rect(size=0.5),
        legend.key.height=unit(0.8,"line"),
        legend.key.width=unit(0.8,"line"),
        legend.text = element_text(margin = margin(0, 0, 0, -0.5, "cm"), color="black", size=9, face="plain"),
        plot.margin = margin(t=0, r=0.2, b=0.1, l=0.2, "cm")) +
  guides(fill=guide_legend(nrow=2,byrow=TRUE))  

ggsave(Fig2b, width = 20, height = 22, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. 2 - feeding.pdf", useDingbats = FALSE)


###########################################################################################################################################
################################# -------- Fig. S2 - Principal coordinate analysis (PCoA)  -------- #######################################
###########################################################################################################################################

df <- read.csv("dataframe.csv", head=T)

df_pcoa <- df[,c(2,19,3,4,5,6,7,8,9,10,11,12)]

habitat_dist <- df_pcoa[,c(4:12)]%>%
                  vegdist(method="euclidian")


permanova_habitats <- adonis2(habitat_dist ~ df_pcoa$habitat, permutations=999)
#PERMANOVA: F:158.46, R²:0.69, p:0.001

permdist_habitats <- betadisper(habitat_dist, group=df_pcoa$habita)
anova(permdist_habitats)
plot(permdist_habitats)
TukeyHSD(permdist_habitats)



pcoa_habitat <- cmdscale(habitat_dist, eig=T, k=2)
habitat_pcoa <- data.frame(pcoa_habitat$points[,1:2])  
habitat_data <- cbind(df_pcoa$location, df_pcoa$habitat, habitat_pcoa)
names(habitat_data) <- c("location","habitat","X1","X2")



habitat_data$pchtype <- NA
habitat_data$pchtype <- ifelse (habitat_data$location == "Noronha",   21, habitat_data$pchtype)
habitat_data$pchtype <- ifelse (habitat_data$location == "Rocas",     22, habitat_data$pchtype)
habitat_data$pchtype <- ifelse (habitat_data$location == "SPSPA",     23, habitat_data$pchtype)
habitat_data$pchtype <- ifelse (habitat_data$location == "Trindade",  24, habitat_data$pchtype)
habitat_data$pchtype <- ifelse (habitat_data$location == "Ascension", 25, habitat_data$pchtype)



FigS2 <-
ggplot(habitat_data , aes(x=X1, y=X2))+ 
    geom_point(aes(color=factor(habitat, levels=c("CCA","EAM","MALG","SAND","ZOAN")), 
                    fill=factor(habitat, levels=c("CCA","EAM","MALG","SAND","ZOAN"))), 
                    shape=habitat_data$pchtype, size=2, stroke=0.5)+
    stat_ellipse(aes(color=habitat), level = 0.95, linetype = 2, size=1)+
    scale_fill_manual(name = "Habitats", values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4","ZOAN"="yellow3"), 0.8))+
    scale_colour_manual(name = "Habitats", values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4","ZOAN"="yellow3"), 1))+
    scale_y_continuous(breaks=c(-80,-60,-40,-20,0,20,40,60,80), limits=c(-80,80), sec.axis = sec_axis(~.x))+
    scale_x_continuous(breaks=c(-80,-60,-40,-20,0,20,40,60,80), limits=c(-90,80), sec.axis = sec_axis(~.x))+
    geom_text(x=-40, y=75, label="PERMANOVA R²= 0.69 | F = 158.46 | p = 0.001", size=4)+
    labs(x=paste("PCoA", 1, "(",round(pcoa_habitat$eig[1]/sum(pcoa_habitat$eig), 3) * 100, "%)"),
         y=paste("PCoA", 2, "(",round(pcoa_habitat$eig[2]/sum(pcoa_habitat$eig), 3) * 100, "%)"))+
    labs(fill="Habitats")+
    annotate("point", x =-60, y = -45, pch=21, size=2, col="black", fill="black")+
    annotate("point", x =-60, y = -51, pch=22, size=2, col="black", fill="black")+
    annotate("point", x =-60, y = -56, pch=23, size=2, col="black", fill="black")+
    annotate("point", x =-60, y = -61.5, pch=24, size=2, col="black", fill="black")+
    annotate("point", x =-60, y = -67, pch=25, size=2, col="black", fill="black")+
    annotate("text",  x =-50, y = -45, label="FNO",  col="black", size=3)+
    annotate("text",  x =-50, y = -51, label="ROC",  col="black", size=3)+
    annotate("text",  x =-50, y = -56, label="SPSA", col="black", size=3)+
    annotate("text",  x =-50, y = -61.5, label="TRI",  col="black", size=3)+
    annotate("text",  x =-50, y = -67, label="ASC",  col="black", size=3)+
    geom_text(x=-53, y=-38, label="Islands", size=4)+
    theme(axis.text.x.bottom = element_text(colour="black", size=10, angle=0, hjust=0.5, vjust=1, face="plain"),
          axis.text.y.left = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
          axis.text.x.top = element_blank(),
          axis.text.y.right = element_blank(),
          #
          panel.grid.minor = element_blank(), 
          panel.background = element_blank(),
          #
          axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.x.top = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.y.left = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.y.right = element_line(size=0.5, colour="black", lineend ="butt"),
          #
          strip.background = element_blank(),
          strip.text.y = element_blank(),
          #
          axis.ticks.length = unit(.1, "cm"),
          axis.ticks.x.bottom = element_line(size = 0.5, colour="black"),
          axis.ticks.y.left = element_line(size = 0.5, colour="black"),
          axis.ticks.x.top = element_blank(),
          axis.ticks.y.right = element_blank(),
          axis.title.x = element_text(hjust=0.5, vjust=0, colour="black", size=10, face="bold"),
          axis.title.y = element_text(hjust=0.5, vjust=3, colour="black", size=10, face="bold"),
          #
          legend.position= c(0.1, 0.2),
          legend.direction="vertical",
          legend.box = NULL,
          legend.justification = "center",
          legend.box.spacing = unit(0.5, "cm"),
          legend.key = element_blank(),
          legend.key.height=unit(1,"line"),
          legend.key.width=unit(1,"line"),
          legend.title=element_text(color="black", size=10, face="bold"))



ggsave(FigS2, width = 15, height = 15, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. S2 - Habitats PCoA.pdf", useDingbats = FALSE)



###########################################################################################################################################
################################# -------- Fig. S3 - Scatterplot Benthic Composition -------- #############################################
###########################################################################################################################################


df <- read.csv("dataframe.csv", head=T)

scatter_benthos <- df[,c(2,4,5,6,7,8,9,10,11,12)]%>%
  gather(functional_group, cover, cca:zoanthid)%>%
  as.data.frame()


benthos_mean <- scatter_benthos %>%
  group_by(location, functional_group)%>%
  summarise_each(funs(mean, sd, se=sd(.)/sqrt(n())))%>%
  as.data.frame()



FigS3 <-
  ggplot() +
  facet_grid(.~factor(location, levels=c("SPSPA","Noronha","Rocas","Ascension","Trindade")))+
  geom_boxplot(data=scatter_benthos, aes(x=cover, y=functional_group))+
  geom_jitter (data=scatter_benthos, aes(x=cover, y=functional_group), 
               color=alpha("gray70",1), 
               fill=alpha("gray70",0.5), 
               height=0.2, shape=21, size=2, stroke=0.5)+
  labs(x =expression("Benthic cover (%)", y = NULL), face="bold")+
  scale_x_continuous(limits=c(-0.5,100), breaks = c(0,20,40,60,80,100), position = "top")+
  scale_y_discrete(limits=c("sediment","other_invertebrates","filter_invertebrates","zoanthid","coral","cyanobacteria","cca","macroalgae","turf"), 
                   labels=c("SAND","OINV","FINV","ZOAN","CORAL","CYAN","CCA","MALG","EAM"))+
  guides(x.sec = "axis", y.sec = "axis")+
  geom_errorbarh(data=benthos_mean, aes(xmax=mean+se, xmin=mean-se, y=functional_group), size=1.2, height = 0, color="black")+
  geom_point(data=benthos_mean, aes(x=mean, y=functional_group), shape=21, size=1.5, colour="black", fill="white", stroke=1.5)+
  theme(axis.text.y.left = element_text(colour="black", size=12, angle=0, hjust=0.5, face="bold"),
        axis.text.x.top = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
        axis.text.y.right = element_blank(),
        axis.text.x.bottom = element_blank(),
        #
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        panel.background = element_rect(fill = NA, color = "black"),
        #
        axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.x.top = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.left = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.right = element_line(size=0.5, colour="black", lineend ="butt"),
        #
        axis.ticks.length = unit(.1, "cm"),
        axis.ticks.x.bottom = element_blank(),
        axis.ticks.y.left = element_line(size = 0.5, colour="black"),
        axis.ticks.x.top = element_line(size = 0.2, colour="black"),
        axis.ticks.y.right = element_blank(),
        #
        axis.title.x = element_text(hjust=0.5, vjust=0.1, color="black", size=12, face="bold"),
        axis.title.y = element_blank(),
        #
        strip.text.x = element_text(size = 12, color = "black", face = "bold"),
        strip.text.y = element_blank(),
        strip.background = element_rect(color="black", fill="grey90", size=0.5, linetype="solid"),
        #
        legend.position = "",
        #
        plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, "cm"))


ggsave(FigS3, width = 25, height = 15, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. S3 - Benthos scatterplot.pdf", useDingbats = FALSE)



###########################################################################################################################################
########################################## -------- Fig. 3 - Feeding pressure  -------- ###################################################
###########################################################################################################################################

df <- read.csv("dataframe.csv", head=T)

df_fish <- df[,c(19,2,3,13,14,15,16,17,18)]
df_fish$total <- rowSums(df_fish[,c(4:9)])

head(df_fish)

df_fish2 <- df_fish%>%
             group_by(location,habitat)%>%
               summarize(across(herbivore_detritivore:total, sum))%>%
                 as.data.frame()%>%
                   complete(location,habitat)%>%
                     replace(is.na(.), 0)%>%
                       as.data.frame()%>%
                         group_by(location) %>%
                           mutate_at(vars(herbivore_detritivore:total), funs(./sum(.)))%>%
                              as.data.frame()%>%
                                 gather(trophic_group, pressure, herbivore_detritivore:total)%>%
                                     as.data.frame()
                        

df_fish2$location[df_fish2$location == "Ascension"] <- "Ascension"
df_fish2$location[df_fish2$location == "SPSPA"]     <- "SPSPA"
df_fish2$location[df_fish2$location == "Noronha"]   <- "Fernando de Noronha"
df_fish2$location[df_fish2$location == "Trindade"]  <- "Trindade Island"
df_fish2$location[df_fish2$location == "Rocas"]     <- "Rocas atoll"


df_fish2$trophic_group[df_fish2$trophic_group == "herbivore_detritivore"] <- "HERD"
df_fish2$trophic_group[df_fish2$trophic_group == "macroalgivore"]         <- "MALG"
df_fish2$trophic_group[df_fish2$trophic_group == "mobile_invertebrate"]   <- "MINV"
df_fish2$trophic_group[df_fish2$trophic_group == "omnivore"]              <- "OMNI"
df_fish2$trophic_group[df_fish2$trophic_group == "sessil_invertebrate"]   <- "SINV"
df_fish2$trophic_group[df_fish2$trophic_group == "territorial_herbivore"] <- "THER"
df_fish2$trophic_group[df_fish2$trophic_group == "total"]                 <- "TOTAL"



Fig3 <-
ggplot(data=df_fish2)+
    facet_grid(.~factor(location, levels=c("SPSPA","Fernando de Noronha","Rocas atoll","Ascension","Trindade Island")))+
    geom_bar(aes(x=pressure, y=trophic_group, 
                 color=factor(habitat, levels=c("CCA","EAM","MALG","SAND","ZOAN")),
                 fill= factor(habitat, levels=c("CCA","EAM","MALG","SAND","ZOAN"))),
             stat="identity", position=position_stack(reverse=TRUE), width=0.9)+
    scale_fill_manual(name = "Habitats",   values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4","ZOAN"="yellow3"), 0.5))+
    scale_colour_manual(name = "Habitats", values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4","ZOAN"="yellow3"), 1.0))+
    labs(x =expression("Proportion of Feeding pressure", y = NULL), face="bold")+
    scale_x_continuous(limits=c(0,1.001), breaks = c(0,0.2,0.4,0.6,0.8,1), position = "top")+
    scale_y_discrete(limits=c("TOTAL","SINV","MINV","OMNI","MALG","THER","HERD"))+
    guides(x.sec = "axis", y.sec = "axis")+
    guides(color = guide_legend(override.aes = list(size = 1)))+
    theme(axis.text.y.left = element_text(colour="black", size=12, angle=0, hjust=0.5, face="bold"),
          axis.text.x.top = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
          axis.text.y.right = element_blank(),
          axis.text.x.bottom = element_blank(),
          #
          panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(), 
          panel.background = element_rect(fill = NA, color = "black"),
          #
          axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.x.top = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.y.left = element_line(size=0.5, colour="black", lineend ="butt"),
          axis.line.y.right = element_line(size=0.5, colour="black", lineend ="butt"),
          #
          axis.ticks.length = unit(.1, "cm"),
          axis.ticks.x.bottom = element_blank(),
          axis.ticks.y.left = element_line(size = 0.5, colour="black"),
          axis.ticks.x.top = element_line(size = 0.2, colour="black"),
          axis.ticks.y.right = element_blank(),
          #
          axis.title.x = element_text(hjust=0.5, vjust=0.1, color="black", size=12, face="bold"),
          axis.title.y = element_blank(),
          #
          strip.text.x = element_text(size = 12, color = "black", face = "bold"),
          strip.text.y = element_blank(),
          strip.background = element_rect(color="black", fill="grey90", size=0.5, linetype="solid"),
          #
          legend.position = "bottom",
          legend.direction = "horizontal",
          legend.box = NULL,
          legend.justification = "center",
          legend.box.spacing = unit(0.3, "cm"),
          legend.key = element_blank(),
          legend.key.size = unit(1, 'cm'),
          legend.key.height = unit(1,"cm"),
          legend.key.width = unit(1,"cm"),
          legend.title = element_text(color="black", size=14, face="bold"),
          legend.text = element_text(size=12),
          #
          plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, "cm"))


ggsave(Fig3, width = 30, height = 15, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. 3 - Feeding pressure.pdf", useDingbats = FALSE)



###########################################################################################################################################
#############################################---------- Bootstrap  ------------############################################################
###########################################################################################################################################

#############################################################
#### ----------- Preparing the community matrix ---------####
#############################################################


df1 <- read.csv("dataframe.csv", head=T, sep=",", dec=".")
df2 <- df1[,c(19,2,3,4:18)]


df3 <- df2[,c(13:18)]
df3$sum <- rowSums(df3)
df3[, -ncol(df3)] <- (df3[, -ncol(df3)] / df3$sum)*100 
df3 <- df3[,-7]


df4 <- cbind(df2[,c(1:12)], df3)


head(df4)
dim(df4)
df4 %>% count(habitat)



CCA <- df4[which(df4$habitat == "CCA"),]
CCA <- CCA[, 4:ncol(CCA)]
mean_CCA <- data.frame(sapply(CCA,Rmisc::CI))


EAM <- df4[which(df4$habitat == "EAM"),]
EAM <- EAM[, 4:ncol(EAM)]
mean_EAM <- data.frame(sapply(EAM,Rmisc::CI))


MALG <- df4[which(df4$habitat == "MALG"),]
MALG <- MALG[, 4:ncol(MALG)]
mean_MALG <- data.frame(sapply(MALG,Rmisc::CI))


SAND <- df4[which(df4$habitat == "SAND"),]
SAND <- SAND[, 4:ncol(SAND)]
mean_SAND <- data.frame(sapply(SAND,Rmisc::CI))



N=1000
group.CCA  <- matrix (NA, ncol=15, nrow=N)
group.EAM  <- matrix (NA, ncol=15, nrow=N)
group.MALG <- matrix (NA, ncol=15, nrow=N)
group.SAND <- matrix (NA, ncol=15, nrow=N)



for (i in 1:N) 
{
  CCA.group <- sample_n(CCA, size = 30)   
  CCA.mean  <- colMeans(CCA.group)       
  group.CCA [i,]  <- CCA.mean                  
}

boot.CCA  <- data.frame(group.CCA)
boot.CCA$habitats <- "CCA"



for (i in 1:N) 
{
  EAM.group <- sample_n(EAM, size = 30)   
  EAM.mean  <- colMeans(EAM.group)       
  group.EAM [i,]  <- EAM.mean                  
}

boot.EAM <- data.frame(group.EAM)
boot.EAM$habitats <- "EAM"



for (i in 1:N) 
{
  MALG.group <- sample_n(MALG, size = 30)   
  MALG.mean  <- colMeans(MALG.group)       
  group.MALG [i,]  <- MALG.mean                  
}

boot.MALG <- data.frame(group.MALG)
boot.MALG$habitats <- "MALG"



for (i in 1:N) 
{
  SAND.group <- sample_n(SAND, size = 30)   
  SAND.mean  <- colMeans(SAND.group)       
  group.SAND [i,]  <- SAND.mean                  
}

boot.SAND <- data.frame(group.SAND)
boot.SAND$habitats <- "SAND"



data_final_boot <- rbind(boot.CCA, boot.EAM, boot.MALG, boot.SAND)
names(data_final_boot) <- c(names(CCA), "habitats")
head(data_final_boot)
dim(data_final_boot)



###########################################################################################################################################
################################ -------- Fig. 4 - Canonical analyses  -------- ###########################################################
###########################################################################################################################################

####################################################
####------ Fish figures to trophic groups ------####
####################################################

HERD <- readPNG("./fish_figures/HERD.png")
HERD <- rasterGrob(HERD, interpolate=TRUE)

MINV <- readPNG("./fish_figures/MINV.png")
MINV <- rasterGrob(MINV, interpolate=TRUE)

SINV <- readPNG("./fish_figures/SINV.png")
SINV <- rasterGrob(SINV, interpolate=TRUE)

OMNI <- readPNG("./fish_figures/OMNI.png")
OMNI<- rasterGrob(OMNI, interpolate=TRUE)

THER <- readPNG("./fish_figures/THER.png")
THER <- rasterGrob(THER, interpolate=TRUE)

MALG <- readPNG("./fish_figures/MALG.png")
MALG <- rasterGrob(MALG, interpolate=TRUE)

benthos <- data_final_boot[,c(1,2,3,4,5,6,7,8,9)]
feeding <- data_final_boot[,c(10,11,12,13,14,15)]



canonical <- cca(feeding ~ ., data=benthos)
head(summary(canonical))


vif.cca(canonical)
RsquareAdj(canonical)$adj.r.squared


anova.cca(canonical, step=1000)
anova.cca(canonical, by="axis", step=1000)
anova.cca(canonical, by="terms", step=1000)


#### ---- Ploting CCA -------####

geral2 <- summary(canonical)
geral3 <- data.frame(geral2$sites[,1:2]) 
geral3 <- cbind(geral3, "habitat"=data_final_boot$habitat)    
geral4 <- data.frame(geral2$species[,1:2])   
geral5 <- data.frame(geral2$biplot[,1:2])



CCA <- 
  ggplot()+ 
  geom_point(data=geral3, aes(x=CCA1, y=CCA2, color=factor(habitat, levels=c("CCA","EAM","MALG","SAND")), 
                              fill=factor(habitat, levels=c("CCA","EAM","MALG","SAND"))), shape=21, size=2, stroke=0.5)+
  scale_fill_manual(name="habitats", values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4"), 0.3))+
  scale_colour_manual(name="habitats", values=alpha(c("CCA"="plum","EAM"="palegreen2","MALG"="green4","SAND"="burlywood4"), 0.8))+
  labs(x=paste("CCA 1 (", format(100 *geral2$cont[[1]][2,1], digits=3), "%)", sep=""),
       y=paste("CCA 2 (", format(100 *geral2$cont[[1]][2,2], digits=3), "%)", sep=""))+
  geom_hline(yintercept=0, linetype="dotted")+
  geom_vline(xintercept=0, linetype="dotted")+
  scale_x_continuous(breaks=c(-2,0,2), limits=c(-2.5,2.5))+
  scale_y_continuous(breaks=c(-2,0,2,4), limits=c(-2.5,4))+
  geom_segment(data=geral4, aes(x=0, xend=CCA1, y=0, yend=CCA2), color="black", linetype=1, size=0.8)+
  geom_text(data=geral4, aes(x=CCA1, y=CCA2, label=c("HERD","MALG","MINV","OMNI","SINV","THER"), 
                             hjust=0.5*(1-sign(CCA1)), vjust=0.5*(1-sign(CCA2))), color="grey20", size=4)+
  annotate("text", x=-1.5, y=4, label="R²Adj.= 0.81 | F = 1935 | p < 0.01", size=4)+
  guides(x.sec = "axis", y.sec = "axis")+
  theme(axis.text.x.bottom = element_text(colour="black", size=10, angle=0, hjust=0.5, vjust=1, face="plain"),
        axis.text.y.left = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
        axis.text.x.top = element_blank(),
        axis.text.y.right = element_blank(),
        #
        panel.grid.minor = element_blank(), 
        panel.background = element_blank(),
        #
        axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.x.top = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.left = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.right = element_line(size=0.5, colour="black", lineend ="butt"),
        #
        strip.background = element_blank(),
        strip.text.y = element_blank(),
        #
        axis.ticks.length = unit(.1, "cm"),
        axis.ticks.x.bottom = element_line(size = 0.0, colour="black"),
        axis.ticks.y.left = element_line(size = 0.5, colour="black"),
        axis.ticks.x.top = element_blank(),
        axis.ticks.y.right = element_blank(),
        axis.title.x = element_text(hjust=0.5, vjust=0, colour="black", size=10, face="bold"),
        axis.title.y = element_text(hjust=0.5, vjust=3, colour="black", size=10, face="bold"),
        #
        legend.position= c(0.08, 0.135),
        legend.direction="vertical",
        legend.box = NULL,
        legend.justification = "center",
        legend.box.spacing = unit(0.5, "cm"),
        legend.key = element_blank(),
        legend.key.height=unit(1,"line"),
        legend.key.width=unit(1,"line"),
        legend.title=element_blank())


ggsave(CCA, width=8, height=8, dpi=600, filename="CCA.pdf", useDingbats=FALSE)


###########################################################################################################################################
################################# -------- Preparing data to Fig 5 and 6  -------- ########################################################
###########################################################################################################################################

##################################
####------ Mean biomass ------####
##################################

census <- read.csv("./database/census_br.csv", sep=";", dec=",")


SPSPA <- 
  census[which(census$locality == "stpauls_rocks"),]%>%
  group_by(transect_id,code)%>%
  summarise(biomass_g = sum(biomass_g))%>%
  spread(key=code, value=biomass_g) %>%
  replace(is.na(.), 0)%>%
  gather(species, biomass, abu_sax:ste_san)%>%
  as.data.frame()%>%
  group_by(species)%>%
  summarize(mean_biomass = (mean(biomass))/40)%>%
  mutate(location="SPSPA")%>%
  as.data.frame()


Noronha <- 
  census[which(census$locality == "noronha"),]%>%
  group_by(transect_id,code)%>%
  summarise(biomass_g = sum(biomass_g))%>%
  spread(key=code, value=biomass_g) %>%
  replace(is.na(.), 0)%>%
  gather(species, biomass, abu_sax:tra_fal)%>%
  as.data.frame()%>% 
  group_by(species)%>%
  summarize(mean_biomass = (mean(biomass))/40)%>%
  mutate(location="Noronha")%>%
  as.data.frame()


Rocas <- 
  census[which(census$locality == "rocas"),]%>%
  group_by(transect_id,code)%>%
  summarise(biomass_g = sum(biomass_g))%>%
  spread(key=code, value=biomass_g) %>%
  replace(is.na(.), 0)%>%
  gather(species, biomass, abu_sax:tha_nor)%>%
  as.data.frame()%>% 
  group_by(species)%>%
  summarize(mean_biomass = (mean(biomass))/40)%>%
  mutate(location="Rocas")%>%
  as.data.frame()


Trindade <- 
  census[which(census$locality == "trindade"),]%>%
  group_by(transect_id,code)%>%
  summarise(biomass_g = sum(biomass_g))%>%
  spread(key=code, value=biomass_g) %>%
  replace(is.na(.), 0)%>% 
  gather(species, biomass, abu_sax:tha_nor)%>%
  as.data.frame()%>% 
  group_by(species)%>%
  summarize(mean_biomass = (mean(biomass))/40)%>%
  mutate(location="Trindade")%>%
  as.data.frame()



asc <- read.csv("./database/census_asc.csv", sep=";", dec=",")

Ascension <- 
  asc%>%
  mutate(biomass = (abun * (allometric_a *(size_cm^allometric_b)))/40)%>%
  group_by(ntrans,code)%>%
  summarise(biomass = sum(biomass))%>%
  spread(key=code, value=biomass) %>%
  replace(is.na(.), 0)%>%
  gather(species, biomass, abu_sax:xyr_bla)%>%
  as.data.frame()%>% 
  group_by(species)%>%
  summarize(mean_biomass = mean(biomass))%>%
  mutate(location="Ascension")%>%
  as.data.frame()


mean_biomass_m <- bind_rows(SPSPA, Noronha, Rocas, Trindade, Ascension)

mean_biomass_m$species[mean_biomass_m$species == "ste_fus"] <- "ste_tri"
mean_biomass_m$species[mean_biomass_m$species == "kyp_spp"] <- "kyp_sp"
mean_biomass_m$species[mean_biomass_m$species == "chr_mul"] <- "azu_mul"

write.csv(mean_biomass_m, "./database/mean_biomass.csv", row.names=FALSE)



############################################
####------ Mean Feeding pressure -------####
############################################

fish_df1 <- read.csv("./database/feeding_data.csv", head=T, dec=",", sep=";")


fish_df1$location[fish_df1$location == "rocas_atoll"]         <- "Rocas"
fish_df1$location[fish_df1$location == "spspa"]               <- "SPSPA"
fish_df1$location[fish_df1$location == "fernando_de_noronha"] <- "Noronha"
fish_df1$location[fish_df1$location == "trindade_island"]     <- "Trindade"
fish_df1$location[fish_df1$location == "ascension"]           <- "Ascension"


feeding <- fish_df1[,c("video_code","location","functional_group","spp_code","feeding_pressure")]%>%
             rename(species = spp_code)
head(feeding)


trophic_group <- unique(feeding[,c("species","functional_group")])

trophic_group$species[trophic_group$species == "ste_fus"] <- "ste_tri"
trophic_group$species[trophic_group$species == "kyp_spp"] <- "kyp_sp"
trophic_group$species[trophic_group$species == "chr_mul"] <- "azu_mul"


ASPSP_fp <- 
feeding[which(feeding$location == "SPSPA"),]%>%
  group_by(video_code,species)%>%
    summarise(pressure = sum(feeding_pressure))%>%
      spread(key=species, value=pressure) %>%
        replace(is.na(.), 0)%>%
          gather(species, pressure, abu_sax:ste_san)%>%
            as.data.frame()%>% 
              group_by(species)%>%
                summarize(mean_fp = (mean(pressure))/2)%>%
                  mutate(location="SPSPA")%>%
                    as.data.frame()
         

Noronha_fp <- 
feeding[which(feeding$location == "Noronha"),]%>%
  group_by(video_code,species)%>%
    summarise(pressure = sum(feeding_pressure))%>%
      spread(key=species, value=pressure) %>%
        replace(is.na(.), 0)%>%
          gather(species, pressure, abu_sax:tha_nor)%>%
            as.data.frame()%>% 
              group_by(species)%>%
                summarize(mean_fp = (mean(pressure))/2)%>%
                  mutate(location="Noronha")%>%
                    as.data.frame()



Rocas_fp <- 
feeding[which(feeding$location == "Rocas"),]%>%
  group_by(video_code,species)%>%
    summarise(pressure = sum(feeding_pressure))%>%
      spread(key=species, value=pressure) %>%
        replace(is.na(.), 0)%>% 
          gather(species, pressure, abu_sax:tha_nor)%>%
            as.data.frame()%>% 
              group_by(species)%>%
                summarize(mean_fp = (mean(pressure))/2)%>%
                  mutate(location="Rocas")%>%
                    as.data.frame()


Trindade_fp <- 
feeding[which(feeding$location == "Trindade"),]%>%
  group_by(video_code,species)%>%
    summarise(pressure = sum(feeding_pressure))%>%
      spread(key=species, value=pressure) %>%
        replace(is.na(.), 0)%>% 
          gather(species, pressure, abu_sax:tha_nor)%>%
            as.data.frame()%>% 
              group_by(species)%>%
                summarize(mean_fp = (mean(pressure))/2)%>%
                  mutate(location="Trindade")%>%
                    as.data.frame()


Ascensao_fp <- 
feeding[which(feeding$location == "Ascension"),]%>%
  group_by(video_code,species)%>%
    summarise(pressure = sum(feeding_pressure))%>%
      spread(key=species, value=pressure) %>%
        replace(is.na(.), 0)%>%
          gather(species, pressure, aca_bah:xyr_bla)%>%
            as.data.frame()%>% 
              group_by(species)%>%
                summarize(mean_fp = (mean(pressure))/2)%>%
                  mutate(location="Ascension")%>%
                    as.data.frame()



mean_feeding_m <- bind_rows(ASPSP_fp, Noronha_fp, Rocas_fp, Trindade_fp, Ascensao_fp)


mean_feeding_m$species[mean_feeding_m$species == "ste_fus"] <- "ste_tri"
mean_feeding_m$species[mean_feeding_m$species == "kyp_spp"] <- "kyp_sp"
mean_feeding_m$species[mean_feeding_m$species == "chr_mul"] <- "azu_mul"


############################################
####--------- Habitats matching --------####
############################################

df <- read.csv("dataframe.csv", head=T)


habitats <- df[,c("video_code","location","habitat")]
head(habitats)


habitat_data <- 
  left_join(feeding, habitats, by=c("video_code","location"))%>%
  filter(!is.na(habitat))%>%
  dplyr::select(location,species,habitat)%>%
  distinct()%>%
  group_by(location,species)%>%
  summarize(habitats = n())%>%
  as.data.frame()


habitat_data$species[habitat_data$species == "ste_fus"] <- "ste_tri"
habitat_data$species[habitat_data$species == "kyp_spp"] <- "kyp_sp"
habitat_data$species[habitat_data$species == "chr_mul"] <- "azu_mul"


final_data <- left_join(mean_feeding_m, mean_biomass_m, by=c("location","species"))%>%
  left_join(habitat_data, by=c("location","species"))%>%
  left_join(trophic_group, by=c("species"))%>%
  filter(!is.na(mean_biomass))%>%
  as.data.frame()


final_data <- final_data[!(final_data$species == "azu_mul"), ]
final_data <- final_data[!(final_data$species == "cep_ful"), ]
final_data <- final_data[!(final_data$functional_group == "macrocarnivore"), ]


coltrophic <- NA
coltrophic <- ifelse (final_data$functional_group == "herbivore_detritivore", "seagreen1",  coltrophic)
coltrophic <- ifelse (final_data$functional_group == "omnivore",              "blue4",      coltrophic)
coltrophic <- ifelse (final_data$functional_group == "mobile_invertebrate",   "orange",     coltrophic)
coltrophic <- ifelse (final_data$functional_group == "sessil_invertebrate",   "gold1",      coltrophic)
coltrophic <- ifelse (final_data$functional_group == "territorial_herbivore", "lightgreen", coltrophic)
coltrophic <- ifelse (final_data$functional_group == "macroalgivore",         "darkgreen",  coltrophic)


final_data_rel <- final_data%>%
  group_by(location)%>%
  mutate(rel_fp = mean_fp/sum(mean_fp),
         rel_bm = mean_biomass/sum(mean_biomass))%>% 
  as.data.frame()


###########################################################################################################################################
############################# -------- Fig 5 Relationship feeding pressure and biomass  -------- ##########################################
###########################################################################################################################################

Fig5a <-
  ggplot(data=final_data)+
  geom_point(aes(x=log(mean_biomass), y=log(mean_fp)), col=alpha(coltrophic, 1), fill=alpha(coltrophic, 0.6),  
             pch=21, size=(final_data$habitats)+2)+
  #geom_text (aes(x=log(mean_abun), y=log(mean_fp), label=species), size=3, fontface="plain") +
  scale_y_continuous(sec.axis = sec_axis(~.x))+
  scale_x_continuous(sec.axis = sec_axis(~.x))+
  xlab("Log (Mean Abundance) ")+
  ylab("Log (Mean Feeding pressure)")+
  theme(axis.text.x.bottom = element_text(colour="black", size=10, angle=0, hjust=0.5, vjust=1, face="plain"),
        axis.text.y.left = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
        axis.text.x.top = element_blank(),
        axis.text.y.right = element_blank(),
        #
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        strip.background = element_blank(),
        #
        axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.x.top =    element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.left =   element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.right =  element_line(size=0.5, colour="black", lineend ="butt"),        
        #
        axis.ticks.length = unit(.2, "cm"),
        axis.ticks.x.bottom = element_line(size = 0.5, colour="black"),
        axis.ticks.y.left =   element_line(size = 0.5, colour="black"),
        axis.ticks.x.top =    element_blank(),
        axis.ticks.y.right =  element_blank(),
        #
        axis.title.x = element_text(hjust=0.5, vjust=0, colour="black", size=10, face="bold"),
        axis.title.y = element_text(hjust=0.5, vjust=4, colour="black", size=10, face="bold"),
        #
        legend.position = "none") 

#######

Fig5b <-
  ggplot(data=final_data_rel, aes(x=rel_bm, y=rel_fp))+
  geom_smooth(method = "lm", level= 0.95, linetype="solid", size=0.7, color="black", fill="lavender", fullrange=TRUE)+
  geom_point(aes(x=rel_bm, y=rel_fp), col=alpha(coltrophic, 1), fill=alpha(coltrophic, 0.6),  
             pch=21, size=(final_data_rel$habitats)+2)+
  geom_text (aes(x=rel_bm, y=rel_fp, label=species), size=3, fontface="plain") +
  scale_y_continuous(sec.axis = sec_axis(~.x), limits=c(0,1))+
  scale_x_continuous(sec.axis = sec_axis(~.x), limits=c(0,1))+
  xlab("Relative Biomass")+ 
  ylab("Relative Feeding pressure")+
  theme(axis.text.x.bottom = element_text(colour="black", size=10, angle=0, hjust=0.5, vjust=1, face="plain"),
        axis.text.y.left = element_text(colour="black", size=10, angle=0, vjust=0.5, face="plain"),
        axis.text.x.top = element_blank(),
        axis.text.y.right = element_blank(),
        #
        panel.grid.minor = element_blank(), 
        panel.background = element_blank(),
        strip.background = element_blank(),
        #
        axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.x.top =    element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.left =   element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.right =  element_line(size=0.5, colour="black", lineend ="butt"),        
        #
        axis.ticks.length = unit(.2, "cm"),
        axis.ticks.x.bottom = element_line(size = 0.5, colour="black"),
        axis.ticks.y.left =   element_line(size = 0.5, colour="black"),
        axis.ticks.x.top =    element_blank(),
        axis.ticks.y.right =  element_blank(),
        #
        axis.title.x = element_text(hjust=0.5, vjust=0, colour="black", size=10, face="bold"),
        axis.title.y = element_text(hjust=0.5, vjust=4, colour="black", size=10, face="bold"),
        #
        legend.position = "none") 



ggsave(Fig5a, width = 15, height = 15, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig. 5a.pdf", useDingbats = FALSE)



###########################################################################################################################################
##################################### -------- Fig 6 Biomass x spp - hyperdominance  -------- #############################################
###########################################################################################################################################


SPSPA <- final_data[final_data$location == "SPSPA",]
asc <- final_data[final_data$location == "Ascension",]
nor <- final_data[final_data$location == "Noronha",]
roc <- final_data[final_data$location == "Rocas",]
tri <- final_data[final_data$location == "Trindade",]

###Update the data to focus on a specific island
fig6 <- ggplot(roc, aes(y=mean_biomass+1, x = reorder(species, desc(mean_biomass)), fill = functional_group)) + 
  geom_bar(position="stack", stat="identity", width = 0.5) +
  scale_fill_manual(values=alpha(c("territorial_herbivore"="yellowgreen",
                                   "herbivore_detritivore"="seagreen1", 
                                   "macroalgivore"="darkgreen", 
                                   "omnivore"="blue4", 
                                   "mobile_invertebrate"="orange", 
                                   "sessil_invertebrate"="gold1"),0.8), 
                    labels=c("THER","HERD","MALG","OMNI","MINV","SINV"))+ 
  scale_y_log10(breaks=c(1,5,25,115)) +
  ggtitle("Rocas") +
  xlab("Species") +
  ylab("Mean Biomass") +
  theme(plot.title = element_text(size = 14, color = "black", face = "bold"),
        #
        axis.text.x.bottom = element_text(colour="black", size=13, angle=90, hjust=0.5, vjust=0.5, face="plain"),
        axis.text.y.left = element_text(colour="black", size=13, angle=0, vjust=0.5, face="plain"),
        axis.text.x.top = element_blank(),
        axis.text.y.right = element_blank(),
        #
        panel.grid.minor = element_blank(), 
        panel.background = element_blank(),
        strip.background = element_blank(),
        #
        axis.line.x.bottom = element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.x.top =    element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.left =   element_line(size=0.5, colour="black", lineend ="butt"),
        axis.line.y.right =  element_line(size=0.5, colour="black", lineend ="butt"),        
        #
        axis.ticks.length = unit(.2, "cm"),
        axis.ticks.x.bottom = element_line(size = 0.5, colour="black"),
        axis.ticks.y.left =   element_line(size = 0.5, colour="black"),
        axis.ticks.x.top =    element_blank(),
        axis.ticks.y.right =  element_blank(),
        #
        axis.title.x = element_text(hjust=0.5, vjust=0, colour="black", size=14, face="bold"),
        axis.title.y = element_text(hjust=0.5, vjust=4, colour="black", size=14, face="bold"),
        #
        legend.position = "") 


ggsave(fig6, width = 15, height = 15, units = "cm", dpi=600, onefile = FALSE, 
       path="./figures_pdf", filename="Fig 6.pdf", useDingbats = FALSE)




###########################################################################################################################################
################################################ -------- GLM Model analyses  -------- ####################################################
###########################################################################################################################################


analise <- glm(log(mean_fp) ~ log(mean_biomass) + as.factor(habitats) + as.factor(functional_group), 
               data=final_data, family=gaussian(link = "identity"))
summary(analise)
hist(residuals(analise))
par(mfrow = c(2,2))
plot(analise)

with(summary(analise), 1 - deviance/null.deviance)

glm.0 <- glm(log(mean_fp) ~ 1, data=final_data)
hist(residuals(glm.0))

anova(analise, glm.0, test="F")



